@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright © 2012 - 2020 Michal Čihař <michal@cihar.com>
 #
@@ -19,11 +18,10 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 """Translation finder, a module to locate translatable files in a filesystem."""
-from __future__ import absolute_import, unicode_literals
 
 from .api import discover
 from .discovery.result import DiscoveryResult
 from .finder import Finder
 
 __all__ = ("Finder", "discover", "DiscoveryResult")
-__version__ = "1.8"
+__version__ = "2.0"
