@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright © 2012 - 2020 Michal Čihař <michal@cihar.com>
 #
@@ -19,7 +18,6 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 """Highlevel API for translation-finder."""
-from __future__ import absolute_import, print_function, unicode_literals
 
 import sys
 from argparse import ArgumentParser
@@ -91,11 +89,14 @@ def cli(stdout=None, args=None):
             "https://github.com/WeblateOrg/translation-finder"
         ),
     )
+    parser.add_argument("--source-language", help="Source language code", default="en")
     parser.add_argument("directory", help="Directory where to perform discovery")
 
     params = parser.parse_args(args)
 
-    for pos, match in enumerate(discover(params.directory)):
+    for pos, match in enumerate(
+        discover(params.directory, source_language=params.source_language)
+    ):
         origin = " ({})".format(match.meta["origin"]) if match.meta["origin"] else ""
         print("== Match {}{} ==".format(pos + 1, origin), file=stdout)
         for key, value in sorted(match.items()):
