@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright © 2012 - 2020 Michal Čihař <michal@cihar.com>
 #
@@ -19,7 +18,6 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 """Base discovery code."""
-from __future__ import absolute_import, unicode_literals
 
 import re
 from itertools import chain
@@ -34,6 +32,33 @@ TOKEN_SPLIT = re.compile(r"([_.-])")
 
 LOCALES = {"latn", "cyrl", "hant", "hans"}
 
+EXTENSION_MAP = (
+    (".po", "po"),
+    ("strings.xml", "aresource"),
+    (".ini", "joomla"),
+    (".csv", "csv"),
+    (".json", "json-nested"),
+    (".dtd", "dtd"),
+    (".php", "php"),
+    (".xlf", "xliff"),
+    (".xliff", "xliff"),
+    (".ts", "ts"),
+    (".resx", "resx"),
+    (".resw", "resx"),
+    (".xlsx", "xlsx"),
+    (".yml", "yaml"),
+    (".yaml", "yaml"),
+    (".properties", "properties"),
+    (".strings", "strings"),
+)
+
+TEMPLATE_REPLACEMENTS = (
+    ("/*/", "/"),
+    ("-*", ""),
+    (".*", ""),
+    ("*", ""),
+)
+
 
 class BaseDiscovery(object):
     """Abstract base class for discovery."""
@@ -67,6 +92,13 @@ class BaseDiscovery(object):
 
         return False
 
+    def detect_format(self, filemask):
+        filemask = filemask.lower()
+        for end, result in EXTENSION_MAP:
+            if filemask.endswith(end):
+                return result
+        return ""
+
     def get_wildcard(self, part):
         """Generate language wilcard for a path part.
 
@@ -104,7 +136,8 @@ class BaseDiscovery(object):
         path = result["filemask"]
         basename = path.rsplit("/", 1)[-1].rsplit(".", 1)[0]
         if "*" in basename:
-            basename = basename.replace(".*", "").replace("-*", "").replace("*", "")
+            for match, replacement in TEMPLATE_REPLACEMENTS:
+                basename = basename.replace(match, replacement)
         new_name = self.new_base_mask.replace("*", basename).lower()
 
         while "/" in path:
@@ -121,13 +154,16 @@ class BaseDiscovery(object):
         return self.finder.has_file(name)
 
     def get_language_aliases(self, language):
-        """Language code aliases"""
+        """Language code aliases."""
         return [language]
 
     def possible_templates(self, language, mask):
-        """Language code aliases"""
+        """Yield possible template filenames."""
         for alias in self.get_language_aliases(language):
             yield mask.replace("*", alias)
+        for match, replacement in TEMPLATE_REPLACEMENTS:
+            if match in mask:
+                yield mask.replace(match, replacement)
 
     def fill_in_template(self, result, source_language=None):
         if "template" not in result:
