@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright © 2012 - 2020 Michal Čihař <michal@cihar.com>
 #
@@ -19,12 +18,10 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 """Individual discovery rules for translation formats."""
-from __future__ import absolute_import, unicode_literals
 
 import json
 from itertools import chain
 
-import six
 from ruamel.yaml import YAML
 from ruamel.yaml.error import YAMLError, YAMLFutureWarning
 
@@ -39,7 +36,7 @@ class GettextDiscovery(BaseDiscovery):
     new_base_mask = "*.pot"
 
     def discover(self):
-        for result in super(GettextDiscovery, self).discover():
+        for result in super().discover():
             if "template" not in result:
                 yield result
                 continue
@@ -51,7 +48,7 @@ class GettextDiscovery(BaseDiscovery):
             yield mono
 
     def fill_in_new_base(self, result):
-        super(GettextDiscovery, self).fill_in_new_base(result)
+        super().fill_in_new_base(result)
         if "new_base" not in result:
             pot_names = [
                 result["filemask"].replace("po/*/", "pot/") + "t",
@@ -143,7 +140,7 @@ class JavaDiscovery(EncodingDiscovery):
 
     def possible_templates(self, language, mask):
         yield mask.replace("_*", "")
-        for result in super(JavaDiscovery, self).possible_templates(language, mask):
+        for result in super().possible_templates(language, mask):
             yield result
 
 
@@ -156,7 +153,7 @@ class RESXDiscovery(BaseDiscovery):
 
     def possible_templates(self, language, mask):
         yield mask.replace(".*", "")
-        for result in super(RESXDiscovery, self).possible_templates(language, mask):
+        for result in super().possible_templates(language, mask):
             yield result
 
     def get_masks(self):
@@ -170,7 +167,7 @@ class RESXDiscovery(BaseDiscovery):
                 continue
             mask[-1] = "{0}.*.{1}".format(base, ext)
             yield {"filemask": "/".join(mask)}
-        for match in super(RESXDiscovery, self).get_masks():
+        for match in super().get_masks():
             yield match
 
 
@@ -196,7 +193,7 @@ class AppStoreDiscovery(BaseDiscovery):
         return self.finder.has_dir(name)
 
     def get_language_aliases(self, language):
-        """Language code aliases"""
+        """Language code aliases."""
         if language == "en":
             return ["en", "en-US", "en-GB", "en-AU"]
         return [language]
@@ -208,6 +205,29 @@ class JSONDiscovery(BaseDiscovery):
     file_format = "json-nested"
     mask = "*.json"
 
+    def detect_dict(self, data, level=0):
+        all_strings = True
+        i18next = False
+        for key, value in data.items():
+            if (
+                level == 0
+                and isinstance(value, dict)
+                and "message" in value
+                and "description" in value
+            ):
+                return False, False, True
+            if not isinstance(key, str):
+                all_strings = False
+                break
+            if not isinstance(value, str):
+                all_strings = False
+                if isinstance(value, dict):
+                    i18next |= self.detect_dict(value, level + 1)[1]
+            elif key.endswith("_plural") or "{{" in value:
+                i18next = True
+
+        return all_strings, i18next, False
+
     def adjust_format(self, result):
         if "template" not in result:
             return
@@ -224,29 +244,15 @@ class JSONDiscovery(BaseDiscovery):
                 return
             if not isinstance(data, dict):
                 return
-            all_strings = True
-            i18next = False
-            for key, value in data.items():
-                if (
-                    isinstance(value, dict)
-                    and "message" in value
-                    and "description" in value
-                ):
-                    result["file_format"] = "webextension"
-                    return
-                if not isinstance(key, six.string_types) or not isinstance(
-                    value, six.string_types
-                ):
-                    all_strings = False
-                    break
-                elif key.endswith("_plural") or "{{" in value:
-                    i18next = True
 
-            if all_strings:
-                if i18next:
-                    result["file_format"] = "i18next"
-                else:
-                    result["file_format"] = "json"
+            all_strings, i18next, webext = self.detect_dict(data)
+
+            if webext:
+                result["file_format"] = "webextension"
+            elif i18next:
+                result["file_format"] = "i18next"
+            elif all_strings:
+                result["file_format"] = "json"
 
 
 class FluentDiscovery(BaseDiscovery):
@@ -256,7 +262,7 @@ class FluentDiscovery(BaseDiscovery):
     mask = "*.ftl"
 
     def get_language_aliases(self, language):
-        """Language code aliases"""
+        """Language code aliases."""
         if language == "en":
             return ["en", "en-US"]
         return [language]
