@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright © 2012 - 2020 Michal Čihař <michal@cihar.com>
 #
@@ -18,7 +17,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
-from __future__ import absolute_import, unicode_literals
 
 import os.path
 from unittest import TestCase
@@ -282,9 +280,18 @@ class GetttetTest(DiscoveryTestCase):
 
     def test_new_base(self):
         discovery = GettextDiscovery(self.get_finder(["foo.fr.po", "foo.po"]))
+        print(list(discovery.discover()))
         self.assert_discovery(
             discovery.discover(),
-            [{"filemask": "foo.*.po", "file_format": "po", "new_base": "foo.po"}],
+            [
+                {"filemask": "foo.*.po", "new_base": "foo.po", "file_format": "po"},
+                {
+                    "filemask": "foo.*.po",
+                    "template": "foo.po",
+                    "new_base": "foo.po",
+                    "file_format": "po-mono",
+                },
+            ],
         )
 
 
@@ -561,6 +568,8 @@ class JSONDiscoveryTest(DiscoveryTestCase):
                     "Source/JavaScriptCore/inspector/protocol/Canvas.json",
                     "Source/JavaScriptCore/inspector/protocol/Target.json",
                     "Source/JavaScriptCore/inspector/protocol/Console.json",
+                    "data/cs/strings.json",
+                    "data/strings.json",
                 ]
             )
         )
@@ -582,6 +591,11 @@ class JSONDiscoveryTest(DiscoveryTestCase):
                     "file_format": "json-nested",
                     "template": "tr/recordings-en.json",
                 },
+                {
+                    "filemask": "data/*/strings.json",
+                    "file_format": "json-nested",
+                    "template": "data/strings.json",
+                },
             ],
         )
 
